"""This is a stub package. It's only function is to raise an exception
about inappropriately using it.
"""

raise ImportError(
    "This is a stub package. It should not be used directly. If you are seeing"
    " this, something has gone wrong. Please reach out to your EntityRisk"
    " contact for support."
)
